==> kado-3.6.20.tgz: package/lang/eng.js <==
'use strict';
/**
 * Kado - Module system for Enterprise Grade applications.
 * Copyright © 2015-2019 NULLIVEX LLC. All rights reserved.
 * Kado <support@kado.org>
 *
 * This file is part of Kado.
 *
 * Kado is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * Kado is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Kado.  If not, see <https://www.gnu.org/licenses/>.
 */

//Kado english language pack
module.exports = {
  '_pack_name': 'English',
  '_pack_version': '1.0',
  '_pack_author': 'Nullivex',
  '_pack_system': 'Kado',
  '_pack_module': 'none',
  '_pack_code': 'eng',
  '_pack_sc': 'en',
  '_pack_flag': 'us',
  'admin_panel': 'Panel',
  'kado': 'Kado',
  'kado_description': 'Development system for Web Applications.',
  'version': 'Version',
  'welcome_to': 'Welcome to',
  'an_error_occurred': 'An error has occurred :(',
  'remove': 'Remove',
  'login': 'Login',
  'sign_in': 'Sign In',
  'toggle_nav': 'Toggle Nav',
  'home': 'Home',
  'list': 'List',
  'create': 'Create',
  'update': 'Update',
  'download': 'Download',
  'edit': 'Edit',
  'staff_title': 'Staff',
  'action': 'Action',
  'active': 'Active',
  'created': 'Created',
  'updated': 'Updated',
  'downloaded': 'Downloaded',
  'saved': 'Saved',
  'list_staff': 'List Staff',
  'create_staff': 'Create Staff',
  'settings': 'Settings',
  'logout': 'Logout',
  'toggle_sidebar': 'Toggle Sidebar',
  'navigation': 'Navigation',
  'create_entry': 'Create Entry',
  'from_the_press': 'From the Press',
  'older': 'Older',
  'newer': 'Newer',
  'title': 'Title',
  'save': 'Save',
  'uri': 'URI',
  'subscribe': 'Subscribe',
  'Dashboard': 'Dashboard',
  'permdenied': 'Permission Denied',
  'invalid_login': 'Invalid login',
  'no_staff_for_args': 'No staff found for given args ',
  'history': 'History',
  'search_results': 'Search Results'
}

==> kado-3.7.10.tgz: package/lang/eng.js <==
'use strict';
/**
 * Kado - Web Application System
 * Copyright © 2015-2019 Bryan Tong, NULLIVEX LLC. All rights reserved.
 * Kado <support@kado.org>
 *
 * This file is part of Kado and bound to the MIT license distributed within.
 */

//Kado english language pack
module.exports = {
  '_pack_name': 'English',
  '_pack_version': '1.0',
  '_pack_author': 'Nullivex',
  '_pack_system': 'Kado',
  '_pack_module': 'none',
  '_pack_code': 'eng',
  '_pack_sc': 'en',
  '_pack_flag': 'us',
  'admin_panel': 'Panel',
  'kado': 'Kado',
  'kado_description': 'Web Application System',
  'version': 'Version',
  'welcome_to': 'Welcome to',
  'an_error_occurred': 'An error has occurred :(',
  'remove': 'Remove',
  'login': 'Login',
  'sign_in': 'Sign In',
  'toggle_nav': 'Toggle Nav',
  'home': 'Home',
  'list': 'List',
  'create': 'Create',
  'update': 'Update',
  'download': 'Download',
  'edit': 'Edit',
  'staff_title': 'Staff',
  'action': 'Action',
  'active': 'Active',
  'created': 'Created',
  'updated': 'Updated',
  'downloaded': 'Downloaded',
  'saved': 'Saved',
  'list_staff': 'List Staff',
  'create_staff': 'Create Staff',
  'settings': 'Settings',
  'logout': 'Logout',
  'toggle_sidebar': 'Toggle Sidebar',
  'navigation': 'Navigation',
  'create_entry': 'Create Entry',
  'from_the_press': 'From the Press',
  'older': 'Older',
  'newer': 'Newer',
  'title': 'Title',
  'save': 'Save',
  'uri': 'URI',
  'subscribe': 'Subscribe',
  'Dashboard': 'Dashboard',
  'permdenied': 'Permission Denied',
  'invalid_login': 'Invalid login',
  'no_staff_for_args': 'No staff found for given args ',
  'history': 'History',
  'search_results': 'Search Results'
}
